﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2011 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System;
using System.Collections.Generic;
using HeuristicLab.Data;

namespace HeuristicLab.Problems.DataAnalysis.Benchmarks {
  public class KeijzerFunctionFour : RegressionToyBenchmark {

    public KeijzerFunctionFour() {
      Name = "Keijzer 4 f(x) = 0.3 * x *sin(2 * PI * x)";
      Description = "Paper: Improving Symbolic Regression with Interval Arithmetic and Linear Scaling" + Environment.NewLine
        + "Authors: Maarten Keijzer" + Environment.NewLine
        + "Function: f(x) = 0.3 * x *sin(2 * PI * x)" + Environment.NewLine
        + "range(train): x = [-1:0.1:1]" + Environment.NewLine
        + "range(test): x = [-1:0.001:1]" + Environment.NewLine
        + "Function Set: x + y, x * y, 1/x, -x, sqrt(x)";
      targetVariable = "Y";
      inputVariables = new List<string>() { "X" };
      trainingPartition = new IntRange(0, 21);
      testPartition = new IntRange(21, 2022);
    }

    protected override List<double> GenerateTarget(List<List<double>> data) {
      double x;
      List<double> results = new List<double>();
      for (int i = 0; i < data[0].Count; i++) {
        x = data[0][i];
        results.Add(0.3 * x * Math.Sin(2 * Math.PI * x));
      }
      return results;
    }

    protected override List<List<double>> GenerateInput() {
      List<List<double>> dataList = new List<List<double>>();
      DoubleRange range = new DoubleRange(-1, 1);
      dataList.Add(RegressionBenchmark.GenerateSteps(range, 0.1));
      dataList[0].AddRange(RegressionBenchmark.GenerateSteps(range, 0.001));

      return dataList;
    }
  }
}
